@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 import inspect
 
+from django.conf import settings
 from rolepermissions.roles import (
     RolesManager, get_user_roles)
 from rolepermissions.permissions import (
@@ -10,7 +11,7 @@ from rolepermissions.permissions import (
 
 def has_role(user, roles):
     """Check if a user has any of the given roles."""
-    if user and user.is_superuser:
+    if _check_superpowers(user):
         return True
 
     if not isinstance(roles, list):
@@ -30,14 +31,14 @@ def has_role(user, roles):
 
 def has_permission(user, permission_name):
     """Check if a user has a given permission."""
-    if user and user.is_superuser:
+    if _check_superpowers(user):
         return True
 
     return permission_name in available_perm_names(user)
 
 def has_object_permission(checker_name, user, obj):
     """Check if a user has permission to perform an action on an object."""
-    if user and user.is_superuser:
+    if _check_superpowers(user):
         return True
 
     checker = PermissionsManager.retrieve_checker(checker_name)
@@ -47,3 +48,18 @@ def has_object_permission(checker_name, user, obj):
         user_roles = [None]
 
     return any([checker(user_role, user, obj) for user_role in user_roles])
+
+
+def _check_superpowers(user):
+    """
+    Check if user is superuser and should have superpowers.
+
+    Default is true to maintain backward compatibility.
+    """
+    key = 'ROLEPERMISSIONS_SUPERUSER_SUPERPOWERS'
+
+    superpowers = getattr(settings, key, True)
+    if not superpowers:
+        return False
+
+    return user and user.is_superuser
