@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 
 from django import template
 
-from rolepermissions.verifications import has_role, has_permission, has_object_permission
+from rolepermissions.checkers import has_role, has_permission, has_object_permission
 
 
 register = template.Library()
@@ -19,7 +19,13 @@ def can_template_tag(user, role):
     return has_permission(user, role)
 
 
-@register.assignment_tag(name='can', takes_context=True)
+if hasattr(register, 'assignment_tag'):
+    tag_registter = register.assignment_tag
+else:
+    tag_registter = register.simple_tag
+
+
+@tag_registter(name='can', takes_context=True)
 def has_permission_template_tag(context, permission, obj, user=None):
     if not user:
         user = context.get('user')
